@@ -24,6 +24,7 @@ from typing import (
     List,
     NamedTuple,
     Optional,
+    Sequence,
     Set,
     Tuple,
     TypeVar,
@@ -370,25 +371,32 @@ class ArgumentInfo:
         )
 
     def __str__(self) -> str:
+        return self.signature()
+
+    def signature(self, add_types: bool = True) -> str:
         prefix = ""
         if self.kind == KeywordArgumentKind.POSITIONAL_ONLY_MARKER:
-            prefix = "*"
+            prefix = "*\u200d"
         elif self.kind == KeywordArgumentKind.NAMED_ONLY_MARKER:
-            prefix = "/"
+            prefix = "/\u200d"
         elif self.kind == KeywordArgumentKind.VAR_NAMED:
-            prefix = "**"
+            prefix = "*\u200d*\u200d"
         elif self.kind == KeywordArgumentKind.VAR_POSITIONAL:
-            prefix = "*"
+            prefix = "*\u200d"
         elif self.kind == KeywordArgumentKind.NAMED_ONLY:
-            prefix = "🏷"
+            prefix = "🏷\u200d"
         elif self.kind == KeywordArgumentKind.POSITIONAL_ONLY:
-            prefix = "⟶"
-        return (
-            f"{prefix}{self.name!s}"
-            f"{(': ' + (' | '.join(f'{s}' for s in self.types))) if self.types else ''}"
-            f"{' =' if self.default_value is not None else ''}"
-            f"{f' {self.default_value!s}' if self.default_value else ''}"
-        )
+            prefix = "⟶\u200d"
+        result = f"{prefix}{self.name!s}"
+        if add_types:
+            result += (
+                f"{(': ' + (' | '.join(f'{s}' for s in self.types))) if self.types else ''}"
+                f"{' =' if self.default_value is not None else ''}"
+                f"{f' {self.default_value!s}' if self.default_value else ''}"
+                if add_types
+                else ""
+            )
+        return result
 
     def __hash__(self) -> int:
         return id(self)
@@ -431,7 +439,7 @@ class ArgumentSpec:
         resolve_variables_until: Any = None,
         dict_to_kwargs: bool = False,
         validate: bool = True,
-    ) -> Tuple[List[Any], Dict[str, Any]]:
+    ) -> Tuple[List[Any], List[Tuple[str, Any]]]:
         from robot.running.arguments.argumentresolver import (
             ArgumentResolver,
             DictToKwargs,
@@ -462,7 +470,7 @@ class ArgumentSpec:
                 resolve_variables_until=resolve_variables_until,
                 dict_to_kwargs=dict_to_kwargs,
             )
-            return cast(Tuple[List[Any], Dict[str, Any]], resolver.resolve(arguments, variables))
+            return cast(Tuple[List[Any], List[Tuple[str, Any]]], resolver.resolve(arguments, variables))
 
         positional, named = NamedArgumentResolver(self.__robot_arguments).resolve(arguments, variables)
         positional, named = VariableReplacer(resolve_variables_until).replace(positional, named, variables)
@@ -618,7 +626,10 @@ class KeywordDoc(SourceEntity):
 
     def _get_signature(self, header_level: int, add_type: bool = True) -> str:
         if add_type:
-            result = f"#{'#'*header_level} {'Library' if self.is_initializer else 'Keyword'} *{self.name}*\n"
+            result = (
+                f"#{'#'*header_level} "
+                f"{(self.libtype or 'Library').capitalize() if self.is_initializer else 'Keyword'} *{self.name}*\n"
+            )
         else:
             if not self.is_initializer:
                 result = f"\n\n#{'#'*header_level} {self.name}\n"
@@ -676,13 +687,12 @@ class KeywordDoc(SourceEntity):
             + ")"
         )
 
-    @property
-    def parameter_signature(self) -> str:
+    def parameter_signature(self, full_signatures: Optional[Sequence[int]] = None) -> str:
         return (
             "("
             + ", ".join(
-                str(a)
-                for a in self.arguments
+                a.signature(full_signatures is None or i in full_signatures)
+                for i, a in enumerate(self.arguments)
                 if a.kind not in [KeywordArgumentKind.POSITIONAL_ONLY_MARKER, KeywordArgumentKind.NAMED_ONLY_MARKER]
             )
             + ")"
@@ -906,10 +916,15 @@ class LibraryDoc:
         )
 
     def get_types(self, type_names: Optional[List[str]]) -> List[TypeDoc]:
+        def alias(s: str) -> str:
+            if s == "boolean":
+                return "bool"
+            return s
+
         if not type_names:
             return []
 
-        return [t for t in self.types if t.name in type_names]
+        return [t for t in self.types if alias(t.name) in type_names]
 
     @property
     def is_deprecated(self) -> bool:
@@ -1715,7 +1730,7 @@ def get_library_doc(
                     ],
                 )
 
-                if get_robot_version() >= (5, 0):
+                if get_robot_version() >= (6, 1):
                     from robot.libdocpkg.datatypes import TypeDoc as RobotTypeDoc
                     from robot.running.arguments.argumentspec import TypeInfo
 
@@ -1959,7 +1974,7 @@ def get_variables_doc(
                                 col_offset=-1,
                                 end_col_offset=-1,
                                 end_line_no=-1,
-                                type="library",
+                                type="variables",
                                 libname=libdoc.name,
                                 libtype=libdoc.type,
                                 longname=f"{libdoc.name}.{kw[0].name}",
@@ -1996,7 +2011,7 @@ def get_variables_doc(
                                     col_offset=-1,
                                     end_col_offset=-1,
                                     end_line_no=-1,
-                                    type="library",
+                                    type="variables",
                                     libname=libdoc.name,
                                     libtype=libdoc.type,
                                     longname=f"{libdoc.name}.{kw[0].name}",
